diff --git a/Html/apps/function_tools/judge.py b/Html/apps/function_tools/judge.py
index 68a94b4..325a409 100644
--- a/Html/apps/function_tools/judge.py
+++ b/Html/apps/function_tools/judge.py
@@ -1,14 +1,14 @@
import os
from ..models.function import FunctionResponse, FunctionStatus
-def judge(filepath:str, name: str, course_id: str, lesson_id: str, root_path:str):
+def judge(filepath:str, name: str, course_id: str, lesson_name: str, root_path:str):
"""Call this method to judge the student's solution after they have completed the problem.
Args:
filepath (`str`): The path to the file containing the student's solution.
name (`str`): The name of the problem.
course_id (`str`): The id of the course.
lesson_id (`str`): The id of the lesson.
root_path (`str`): The root path of the user's workspace project.
Returns:
@@ -1,14 +1,14 @@
name (`str`): The name of the problem.
course_id (`str`): The id of the course.
- lesson_id (`str`): The id of the lesson.
+ lesson_name (`str`): The name of the lesson.
root_path (`str`): The root path of the user's workspace project.
Returns: